==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/TABID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TABID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TABID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TABID_Type", propOrder = {
    "tabcode",
    "tabdescription"
})
public class TABID_Type {

    @XmlElement(name = "TABCODE", required = true)
    protected String tabcode;
    @XmlElement(name = "TABDESCRIPTION")
    protected String tabdescription;

    /**
     * Obtient la valeur de la propriété tabcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABCODE() {
        return tabcode;
    }

    /**
     * Définit la valeur de la propriété tabcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABCODE(String value) {
        this.tabcode = value;
    }

    /**
     * Obtient la valeur de la propriété tabdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABDESCRIPTION() {
        return tabdescription;
    }

    /**
     * Définit la valeur de la propriété tabdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABDESCRIPTION(String value) {
        this.tabdescription = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TABID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TABID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TABID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TABID_Type", propOrder = {
    "tabcode",
    "tabdescription"
})
public class TABID_Type {

    @XmlElement(name = "TABCODE", required = true)
    protected String tabcode;
    @XmlElement(name = "TABDESCRIPTION")
    protected String tabdescription;

    /**
     * Gets the value of the tabcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABCODE() {
        return tabcode;
    }

    /**
     * Sets the value of the tabcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABCODE(String value) {
        this.tabcode = value;
    }

    /**
     * Gets the value of the tabdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABDESCRIPTION() {
        return tabdescription;
    }

    /**
     * Sets the value of the tabdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABDESCRIPTION(String value) {
        this.tabdescription = value;
    }

}
